CREATE DATABASE 'mnogosearch.gdb';


CREATE GENERATOR rec_id_GEN;


CREATE TABLE url (
  rec_id          INT                  NOT NULL PRIMARY KEY,
  url             CHAR(128) DEFAULT '' NOT NULL,
  status          INT       DEFAULT  0 NOT NULL,
  hops            INT       DEFAULT  0 NOT NULL,
  crc32           INT       DEFAULT  0 NOT NULL,
  docsize         INT       DEFAULT  0 NOT NULL,
  next_index_time INT       DEFAULT  0 NOT NULL,
  last_mod_time   INT       DEFAULT  0 NOT NULL,
  referrer        INT       DEFAULT  0 NOT NULL,
  seed            INT       DEFAULT  0 NOT NULL,
  bad_since_time  INT       DEFAULT  0 NOT NULL,
  site_id	  INT,
  server_id	  INT,
  pop_rank	  FLOAT     DEFAULT  0 NOT NULL
);

CREATE INDEX         url_crc             ON url (crc32);
CREATE INDEX         url_seed            ON url (seed);
CREATE UNIQUE  INDEX url_url             ON url (url);
CREATE INDEX         url_referrer        ON url (referrer);
CREATE INDEX         url_bad_since_time  ON url (bad_since_time);
CREATE INDEX         url_next_index_time ON url (next_index_time);



CREATE TABLE urlinfo (
  url_id  INT           NOT NULL,
  sname   VARCHAR(64)   NOT NULL,
  sval    VARCHAR(1024) NOT NULL
);

CREATE INDEX urlinfo_id ON urlinfo (url_id);




CREATE TABLE dict (
  word     VARCHAR(32) NOT NULL,
  url_id   INT      NOT NULL,
  intag    INT      NOT NULL
);

CREATE   INDEX dict_url_id  ON dict (url_id);
CREATE   INDEX dict_word    ON dict (word);



CREATE TABLE qtrack (
  qwords  varchar(63) DEFAULT '' NOT NULL,
  ip      varchar(16) DEFAULT '' NOT NULL,
  qtime   int         DEFAULT 0  NOT NULL,
  found   int         DEFAULT 0  NOT NULL,
  ps      int         DEFAULT 0  NOT NULL,
  np      int         DEFAULT 0  NOT NULL,
  m       varchar(63) DEFAULT '' NOT NULL,
  wm      varchar(63) DEFAULT '' NOT NULL,
  o       int         DEFAULT 0  NOT NULL,
  t       varchar(63) DEFAULT '' NOT NULL,
  cat     varchar(63) DEFAULT '' NOT NULL,
  ul      varchar(63) DEFAULT '' NOT NULL,
  wf      varchar(63) DEFAULT '' NOT NULL,
  g       varchar(63) DEFAULT '' NOT NULL,
  tmplt   varchar(63) DEFAULT '' NOT NULL
);


create table server (
	rec_id		int not null primary key,
	enabled		int		default 0	not null,
	url		varchar(128)	default ''	not null,
	alias		varchar(128)	default ''	not null,
	period		int		default 604800	not null,
	tag		varchar(16)	default ''	not null,
	category	varchar(16)	default ''	not null,
	charset		varchar(40)	default ''	not null,
	lang		varchar(32)	default ''	not null,
	basic_auth	varchar(64)	default ''	not null,
	proxy		varchar(64)	default ''	not null,
	proxy_auth	varchar(64)	default ''	not null,
	
	maxhops		int		default 9999	not null,
	gindex		int		default 1	not null,
	follow		int		default 1	not null,
	use_robots	int		default 1	not null,
	use_clones	int		default 1	not null,
	max_net_errors	int		default 16	not null,
	net_delay_time	int		default 86400	not null,
	read_timeout	int		default 90	not null,
	
	command		char(1)		default 'S'	not null,
	match_type	int		default 1	not null,
	case_sense	int		default 0	not null,
	nomatch		int		default 0	not null,
	ordre		int		default 0	not null,
	parent		int		default 0	not null,
	weight		float		default 1	not null,
	pop_weight	float		default 0	not null
);

CREATE UNIQUE INDEX srv_url     ON server (url);
CREATE        INDEX srv_ordre   ON server (ordre);
CREATE        INDEX srv_parent  ON server (parent);
CREATE        INDEX srv_command ON server (command);

create table links (
       ot	   int,
       k	   int,
       weight	   float     	default 0
);

CREATE UNIQUE INDEX links_links ON links (ot, k);
CREATE        INDEX links_ot    ON links (ot);
CREATE        INDEX links_k     ON links (k);
